@@ -125,8 +125,8 @@ class HTMLPurifier_Strategy_MakeWellFormedTest extends HTMLPurifier_StrategyHarn
 
     function testNestedUl() {
         $this->assertResult(
-            '<ul><ul></ul></ul>',
-            '<ul><li><ul></ul></li></ul>'
+            '<ul><ul><li>foo</li></ul></ul>',
+            '<ul><li><ul><li>foo</li></ul></li></ul>'
         );
     }
 
@@ -137,6 +137,13 @@ class HTMLPurifier_Strategy_MakeWellFormedTest extends HTMLPurifier_StrategyHarn
         );
     }
 
+    function testNoAutocloseIfNoParentsCanAccomodateTag() {
+        $this->assertResult(
+            '<table><tr><td><li>foo</li></td></tr></table>',
+            '<table><tr><td>foo</td></tr></table>'
+        );
+    }
+
 }
 
 // vim: et sw=4 sts=4
